// Copyright (c) 2020–2021 Ruslan Makarov (https://github.com/all3y3zonme)
// Permission to use, copy, modify, and/or distribute this software for any
// purpose with or without fee is hereby granted, provided that the above
// copyright notice and this permission notice appear in all copies.
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
// WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
// ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
// WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
// ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
// OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
import fetch from 'node-fetch';
export class RucaptchaApi {
    constructor(apiKey, settings) {
        this.sendPictureToSolveRouteURL =
            settings?.sendPictureRoute || 'https://rucaptcha.com/in.php';
        this.getPictureSolveRouteURL =
            settings?.getPictureRoute || 'https://rucaptcha.com/res.php';
        this.delay = settings?.delay || 3000;
        this.retry = settings?.retry || 5;
        this.apiKey = apiKey;
    }
    async solveCaptcha(base64Image) {
        const pictureKey = await this.sendPicture(base64Image);
        for (let i = 0; i < this.retry; i++) {
            await this.sleep(this.delay);
            const solve = await this.checkSolve(pictureKey);
            if (solve)
                return solve;
        }
    }
    async sendPicture(base64Image) {
        const response = await fetch(this.sendPictureToSolveRouteURL, {
            method: 'POST',
            body: JSON.stringify({
                method: 'base64',
                key: this.apiKey,
                body: base64Image,
                json: 1,
                header_acao: 1,
            }),
        });
        const parsedResponse = await response.json();
        return parsedResponse.request;
    }
    async checkSolve(pictureKey) {
        const response = await fetch(`${this.getPictureSolveRouteURL}?key=${this.apiKey}&action=get&id=${pictureKey}&json=1&header_acao=1,`);
        const decodedResponse = await response.text();
        if (decodedResponse !== 'CAPCHA_NOT_READY') {
            const parsedResponse = JSON.parse(decodedResponse);
            return parsedResponse.request;
        }
    }
    async sleep(ms) {
        return new Promise((resolve) => {
            setTimeout(() => {
                resolve();
            }, ms);
        });
    }
}
